This sizeshape module contains method for calculating a 1D linear projection and the Mahalanobis distance in size and shape space for a given reference configurational distribution.

## Installation 

This module is not installed by default. Add `--enable-modules=sizeshape` to your './configure' command when building PLUMED to enable these features.

